==> ejc-bfyjerp-impl-3.0.0-20250107.080915-92-sources.jar: com/ejianc/business/bid/bean/ProjectPersonAffirmEntity.java <==
package com.ejianc.business.bid.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 投标管理-确认项目经理及技术负责人
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_project_person_affirm")
public class ProjectPersonAffirmEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="registration_id")
    private Long registrationId; // 项目报名表Id
    @TableField(value="opportunity_id")
    private Long opportunityId; // 商机登记表Id
    @TableField(value="opportunity_bill_code")
    private Long opportunityBillCode; // 商机登记单据编码
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="qualification_type_id")
    private Long qualificationTypeId; // 资质类别id
    @TableField(value="qualification_type_code")
    private String qualificationTypeCode; // 资质类别编码
    @TableField(value="qualification_type_name")
    private String qualificationTypeName; // 资质类别名称
    @TableField(value="qualification_level_id")
    private Long qualificationLevelId; // 资质等级id
    @TableField(value="qualification_level_code")
    private String qualificationLevelCode; // 资质等级编码
    @TableField(value="qualification_level_name")
    private String qualificationLevelName; // 资质等级名称
    @TableField(value="project_period")
    private String projectPeriod; // 工期
    @TableField(value="bidding_control_mmy")
    private BigDecimal biddingControlMmy; // 控制价(万元)
    @TableField(value="is_bid_winning")
    private Integer isBidWinning; // 是否中标：0-否，1-是
    @TableField(value="documenter_id")
    private Long documenterId; // 资料员id
    @TableField(value="documenter_name")
    private String documenterName; // 资料员名称
    @TableField(value="person_social_security_demand")
    private String personSocialSecurityDemand; // 人员社保要求
    @TableField(value="project_manager_demand")
    private String projectManagerDemand; // 项目经理要求
    @TableField(value = "tech_manager_demand")
    private String techManagerDemand;//技术负责人要求
    @TableField(value="project_manager_id")
    private String projectManagerId; // 项目经理id
    @TableField(value="project_manager_name")
    private String projectManagerName; // 项目经理
    @TableField(value="tech_manager_id")
    private String techManagerId; // 技术负责人id
    @TableField(value="tech_manager_name")
    private String techManagerName; // 技术负责人名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    @TableField(value = "employee_id")
    private Long employeeId; // 编制人id
    @TableField(value = "employee_name")
    private String employeeName; // 编制人名称

    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称

    public String getTechManagerDemand() {
        return techManagerDemand;
    }

    public void setTechManagerDemand(String techManagerDemand) {
        this.techManagerDemand = techManagerDemand;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getTechManagerId() {
        return techManagerId;
    }

    public void setTechManagerId(String techManagerId) {
        this.techManagerId = techManagerId;
    }

    public String getTechManagerName() {
        return techManagerName;
    }

    public void setTechManagerName(String techManagerName) {
        this.techManagerName = techManagerName;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getRegistrationId() {
        return registrationId;
    }

    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    public Long getOpportunityId() {
        return opportunityId;
    }

    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public Long getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(Long opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public Long getQualificationTypeId() {
        return qualificationTypeId;
    }

    public void setQualificationTypeId(Long qualificationTypeId) {
        this.qualificationTypeId = qualificationTypeId;
    }
    public String getQualificationTypeCode() {
        return qualificationTypeCode;
    }

    public void setQualificationTypeCode(String qualificationTypeCode) {
        this.qualificationTypeCode = qualificationTypeCode;
    }
    public String getQualificationTypeName() {
        return qualificationTypeName;
    }

    public void setQualificationTypeName(String qualificationTypeName) {
        this.qualificationTypeName = qualificationTypeName;
    }
    public Long getQualificationLevelId() {
        return qualificationLevelId;
    }

    public void setQualificationLevelId(Long qualificationLevelId) {
        this.qualificationLevelId = qualificationLevelId;
    }
    public String getQualificationLevelCode() {
        return qualificationLevelCode;
    }

    public void setQualificationLevelCode(String qualificationLevelCode) {
        this.qualificationLevelCode = qualificationLevelCode;
    }
    public String getQualificationLevelName() {
        return qualificationLevelName;
    }

    public void setQualificationLevelName(String qualificationLevelName) {
        this.qualificationLevelName = qualificationLevelName;
    }
    public String getProjectPeriod() {
        return projectPeriod;
    }

    public void setProjectPeriod(String projectPeriod) {
        this.projectPeriod = projectPeriod;
    }
    public BigDecimal getBiddingControlMmy() {
        return biddingControlMmy;
    }

    public void setBiddingControlMmy(BigDecimal biddingControlMmy) {
        this.biddingControlMmy = biddingControlMmy;
    }
    public Integer getIsBidWinning() {
        return isBidWinning;
    }

    public void setIsBidWinning(Integer isBidWinning) {
        this.isBidWinning = isBidWinning;
    }
    public Long getDocumenterId() {
        return documenterId;
    }

    public void setDocumenterId(Long documenterId) {
        this.documenterId = documenterId;
    }
    public String getDocumenterName() {
        return documenterName;
    }

    public void setDocumenterName(String documenterName) {
        this.documenterName = documenterName;
    }
    public String getPersonSocialSecurityDemand() {
        return personSocialSecurityDemand;
    }

    public void setPersonSocialSecurityDemand(String personSocialSecurityDemand) {
        this.personSocialSecurityDemand = personSocialSecurityDemand;
    }
    public String getProjectManagerDemand() {
        return projectManagerDemand;
    }

    public void setProjectManagerDemand(String projectManagerDemand) {
        this.projectManagerDemand = projectManagerDemand;
    }
    public String getProjectManagerId() {
        return projectManagerId;
    }

    public void setProjectManagerId(String projectManagerId) {
        this.projectManagerId = projectManagerId;
    }
    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20250121.091128-116-sources.jar: com/ejianc/business/bid/bean/ProjectPersonAffirmEntity.java <==
package com.ejianc.business.bid.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 投标管理-确认项目经理及技术负责人
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_project_person_affirm")
public class ProjectPersonAffirmEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="registration_id")
    private Long registrationId; // 项目报名表Id
    @TableField(value="opportunity_id")
    private Long opportunityId; // 商机登记表Id
    @TableField(value="opportunity_bill_code")
    private Long opportunityBillCode; // 商机登记单据编码
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="qualification_type_id")
    private Long qualificationTypeId; // 资质类别id
    @TableField(value="qualification_type_code")
    private String qualificationTypeCode; // 资质类别编码
    @TableField(value="qualification_type_name")
    private String qualificationTypeName; // 资质类别名称
    @TableField(value="qualification_level_id")
    private Long qualificationLevelId; // 资质等级id
    @TableField(value="qualification_level_code")
    private String qualificationLevelCode; // 资质等级编码
    @TableField(value="qualification_level_name")
    private String qualificationLevelName; // 资质等级名称
    @TableField(value="project_period")
    private String projectPeriod; // 工期
    @TableField(value="bidding_control_mmy")
    private BigDecimal biddingControlMmy; // 控制价(万元)
    @TableField(value="is_bid_winning")
    private Integer isBidWinning; // 是否中标：0-否，1-是
    @TableField(value="documenter_id")
    private Long documenterId; // 资料员id
    @TableField(value="documenter_name")
    private String documenterName; // 资料员名称
    @TableField(value="person_social_security_demand")
    private String personSocialSecurityDemand; // 人员社保要求
    @TableField(value="project_manager_demand")
    private String projectManagerDemand; // 项目经理要求
    @TableField(value = "tech_manager_demand")
    private String techManagerDemand;//技术负责人要求
    @TableField(value="project_manager_id")
    private String projectManagerId; // 项目经理id
    @TableField(value="project_manager_name")
    private String projectManagerName; // 项目经理
    @TableField(value="tech_manager_id")
    private String techManagerId; // 技术负责人id
    @TableField(value="tech_manager_name")
    private String techManagerName; // 技术负责人名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    @TableField(value = "employee_id")
    private Long employeeId; // 编制人id
    @TableField(value = "employee_name")
    private String employeeName; // 编制人名称

    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="pusher_name")
    private String pusherName; // 抄送人名称
    @TableField(value="pusher_id")
    private String pusherId; // 抄送人

    public String getPusherId() {
        return pusherId;
    }

    public void setPusherId(String pusherId) {
        this.pusherId = pusherId;
    }

    public String getPusherName() {
        return pusherName;
    }

    public void setPusherName(String pusherName) {
        this.pusherName = pusherName;
    }

    public String getTechManagerDemand() {
        return techManagerDemand;
    }

    public void setTechManagerDemand(String techManagerDemand) {
        this.techManagerDemand = techManagerDemand;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getTechManagerId() {
        return techManagerId;
    }

    public void setTechManagerId(String techManagerId) {
        this.techManagerId = techManagerId;
    }

    public String getTechManagerName() {
        return techManagerName;
    }

    public void setTechManagerName(String techManagerName) {
        this.techManagerName = techManagerName;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getRegistrationId() {
        return registrationId;
    }

    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    public Long getOpportunityId() {
        return opportunityId;
    }

    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public Long getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(Long opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public Long getQualificationTypeId() {
        return qualificationTypeId;
    }

    public void setQualificationTypeId(Long qualificationTypeId) {
        this.qualificationTypeId = qualificationTypeId;
    }
    public String getQualificationTypeCode() {
        return qualificationTypeCode;
    }

    public void setQualificationTypeCode(String qualificationTypeCode) {
        this.qualificationTypeCode = qualificationTypeCode;
    }
    public String getQualificationTypeName() {
        return qualificationTypeName;
    }

    public void setQualificationTypeName(String qualificationTypeName) {
        this.qualificationTypeName = qualificationTypeName;
    }
    public Long getQualificationLevelId() {
        return qualificationLevelId;
    }

    public void setQualificationLevelId(Long qualificationLevelId) {
        this.qualificationLevelId = qualificationLevelId;
    }
    public String getQualificationLevelCode() {
        return qualificationLevelCode;
    }

    public void setQualificationLevelCode(String qualificationLevelCode) {
        this.qualificationLevelCode = qualificationLevelCode;
    }
    public String getQualificationLevelName() {
        return qualificationLevelName;
    }

    public void setQualificationLevelName(String qualificationLevelName) {
        this.qualificationLevelName = qualificationLevelName;
    }
    public String getProjectPeriod() {
        return projectPeriod;
    }

    public void setProjectPeriod(String projectPeriod) {
        this.projectPeriod = projectPeriod;
    }
    public BigDecimal getBiddingControlMmy() {
        return biddingControlMmy;
    }

    public void setBiddingControlMmy(BigDecimal biddingControlMmy) {
        this.biddingControlMmy = biddingControlMmy;
    }
    public Integer getIsBidWinning() {
        return isBidWinning;
    }

    public void setIsBidWinning(Integer isBidWinning) {
        this.isBidWinning = isBidWinning;
    }
    public Long getDocumenterId() {
        return documenterId;
    }

    public void setDocumenterId(Long documenterId) {
        this.documenterId = documenterId;
    }
    public String getDocumenterName() {
        return documenterName;
    }

    public void setDocumenterName(String documenterName) {
        this.documenterName = documenterName;
    }
    public String getPersonSocialSecurityDemand() {
        return personSocialSecurityDemand;
    }

    public void setPersonSocialSecurityDemand(String personSocialSecurityDemand) {
        this.personSocialSecurityDemand = personSocialSecurityDemand;
    }
    public String getProjectManagerDemand() {
        return projectManagerDemand;
    }

    public void setProjectManagerDemand(String projectManagerDemand) {
        this.projectManagerDemand = projectManagerDemand;
    }
    public String getProjectManagerId() {
        return projectManagerId;
    }

    public void setProjectManagerId(String projectManagerId) {
        this.projectManagerId = projectManagerId;
    }
    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    
}
